summaryrefslogtreecommitdiff
path: root/sys/kern/kern_exit.c
diff options
context:
space:
mode:
authorPhilip Guenthe <guenther@cvs.openbsd.org>2011-07-05 04:48:03 +0000
committerPhilip Guenthe <guenther@cvs.openbsd.org>2011-07-05 04:48:03 +0000
commit0e36778a06f5746ef60cadc41c445d6f5b6cc647 (patch)
tree28f4fa5e7600b312b1d6084db8548e11c7f9d783 /sys/kern/kern_exit.c
parenta7942e7ec8d68c52b4e9833fffb6c7810fde7f15 (diff)
Recommit the reverted sigacts change now that the NFS use-after-free
problem has been tracked down. This fixes the sharing of the signal handling state: shared bits go in sigacts, per-rthread bits goes in struct proc. ok deraadt@
Diffstat (limited to 'sys/kern/kern_exit.c')
-rw-r--r--sys/kern/kern_exit.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/kern/kern_exit.c b/sys/kern/kern_exit.c
index 03b6ed37f50..078249f1e7f 100644
--- a/sys/kern/kern_exit.c
+++ b/sys/kern/kern_exit.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: kern_exit.c,v 1.100 2011/04/18 21:44:56 guenther Exp $ */
+/* $OpenBSD: kern_exit.c,v 1.101 2011/07/05 04:48:02 guenther Exp $ */
/* $NetBSD: kern_exit.c,v 1.39 1996/04/22 01:38:25 christos Exp $ */
/*
@@ -176,7 +176,6 @@ exit1(struct proc *p, int rv, int flags)
if (p->p_flag & P_PROFIL)
stopprofclock(p);
p->p_ru = pool_get(&rusage_pool, PR_WAITOK);
- p->p_sigignore = ~0;
p->p_siglist = 0;
timeout_del(&p->p_realit_to);
timeout_del(&p->p_stats->p_virt_to);
@@ -305,11 +304,12 @@ exit1(struct proc *p, int rv, int flags)
/*
* Notify parent that we're gone. If we have P_NOZOMBIE
* or parent has the P_NOCLDWAIT flag set, notify process 1
* instead (and hope it will handle this situation).
*/
if ((p->p_flag & P_NOZOMBIE) ||
- (pr->ps_pptr->ps_mainproc->p_flag & P_NOCLDWAIT)) {
+ (pr->ps_pptr->ps_mainproc->p_sigacts->ps_flags &
+ SAS_NOCLDWAIT)) {
struct process *ppr = pr->ps_pptr;
proc_reparent(pr, initproc->p_p);
/*
@@ -305,11 +304,12 @@ exit1(struct proc *p, int rv, int flags)
/*
* Notify parent that we're gone. If we have P_NOZOMBIE
- * or parent has the P_NOCLDWAIT flag set, notify process 1
+ * or parent has the SAS_NOCLDWAIT flag set, notify process 1
* instead (and hope it will handle this situation).
*/